@@ -19,6 +19,8 @@ import domutils.radar_tools as radar_tools
 import domutils.geo_tools as geo_tools
 from collections import Counter
 #from pathlib import Path
+
+from pathlib import Path
 import domcmc.fst_tools as fst_tools
 
 def make_input_db(filein, this_time):
@@ -673,11 +675,12 @@ def find_sample_entry(src_dir, file_type, variable=None, prefix=None):
 
     found = False
     if file_type == 'fst':
-        file_list = sorted(os.path(src_dir).glob(prefix))
-        file_list = sorted(os.path(src_dir).glob(prefix))
-        file_list = sorted(os.path(src_dir).glob(prefix))
+        file_list = sorted(Path(src_dir).glob(prefix))
+        file_list = sorted(Path(src_dir).glob(prefix))
+        file_list = sorted(Path(src_dir).glob(prefix))
         for this_file in file_list:
             if this_file.is_file():
+                
                 out_dict = fst_tools.get_data(str(this_file), var_name=variable, latlon=True )
                 if out_dict is not None:
                     found = True
