@@ -2,6 +2,9 @@
 
 #to run a single test: superobs_test_avg_obs
 #  python unittest_superobs.py TestMethods.test_superobs_fake_data
+#  python unittest_superobs.py TestMethods.test_qcavg_data
+#  python unittest_superobs.py TestMethods.test_thinning_data
+
 
 
 import unittest
@@ -44,6 +47,7 @@ class TestMethods(unittest.TestCase):
         range_start = 0.
         range_end = 0.
         nyquist = 1.
+        flag = 0
        
         #full path of radvelso module
         radvelso_dir = os.path.dirname(radvelso.__file__)
@@ -54,11 +58,7 @@ class TestMethods(unittest.TestCase):
 
         # sqlite file from fake data
         #flush fileouts if it already exists
-<<<<<<< HEAD
         pathfile_from_source=f"{package_dir}/radvelso/tests/test_result/sqlite_files/2021010112_ra"
-=======
-        pathfile_from_source=f"{package_dir}/radvelso/test_result/sqlite_files/2021010112_ra"
->>>>>>> 5b48a179856217af1f227cde69e450027fa1cb25
         if os.path.isfile(pathfile_from_source):
           os.remove(pathfile_from_source)
         pathfile_superobs=f"{package_dir}/radvelso/tests/test_result/sqlite_files/{date}12_superobbed_fake_data.sqlite"
@@ -99,10 +99,10 @@ class TestMethods(unittest.TestCase):
                            (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?) '''
 
         data_cmd   = ''' INSERT INTO DATA (
-                           ID_DATA,  ID_OBS, RANGE, OBSVALUE, HALF_DELTA_AZIMUTH, HALF_DELTA_RANGE
+                           ID_DATA,  ID_OBS, RANGE, OBSVALUE, HALF_DELTA_AZIMUTH, HALF_DELTA_RANGE, flag
                          )
                          VALUES
-                           (?,?,?,?,?,?) '''
+                           (?,?,?,?,?,?,?) '''
         source_azimuths  = np.array([0., 22.5, 45., 67.5 ,90., 112.5, 135, 157.5, 180., 202.5, 225.,
                                      247.5, 270., 292.5, 315, 337.5])
         source_obsvalues = np.array([5., 10., 15., 20., 25., 30., 35., 40. ,-5.,-10.,-15.,-20., 
@@ -123,7 +123,7 @@ class TestMethods(unittest.TestCase):
           for range_obs  in ranges: 
             obsvalue=obsvalue/id_data
             #insert into data
-            data_values = (id_data, id_obs, range_obs, obsvalue, half_delta_azimuth, half_delta_range)
+            data_values = (id_data, id_obs, range_obs, obsvalue, half_delta_azimuth, half_delta_range, flag)
             conn.execute(data_cmd, data_values)
             id_data += 1
           
@@ -137,21 +137,15 @@ class TestMethods(unittest.TestCase):
         window_width = 6.0
         infile_list = [f'{pathfile_from_source}']
         desired_radar_list = "CASXX"
-<<<<<<< HEAD
         pathout = f"{package_dir}/radvelso/tests/test_result/sqlite_files/"
-=======
-        pathout = f"{package_dir}/radvelso/test_result/sqlite_files/"
->>>>>>> 5b48a179856217af1f227cde69e450027fa1cb25
         outfile_struc = '%Y%m%d%H_superobbed_fake_data.sqlite'
         timing = False
         ops_run_name = None
         n_rays = 20
         delta_range = 10000
         n_cpus = 1
-<<<<<<< HEAD
         obs_percentage = 0
-=======
->>>>>>> 5b48a179856217af1f227cde69e450027fa1cb25
+        obs_nyquist = 0
         radvelso.compute_average(center_time=center_time,
                                  window_width=window_width, 
                                  infile_list=infile_list,
@@ -163,7 +157,8 @@ class TestMethods(unittest.TestCase):
                                  n_rays = n_rays,
                                  delta_range = delta_range,   
                                  n_cpus = n_cpus,
-                                 obs_percentage = obs_percentage)
+                                 obs_percentage = obs_percentage,
+                                 obs_nyquist = obs_nyquist)
 
         
         #comparison between  average computation from code (superobs_sqlite) and result by hand 
@@ -196,6 +191,106 @@ class TestMethods(unittest.TestCase):
         # comparation
         test_superobs_fake_data=  (np.allclose(calculated_result_hand,results,atol=1e-4))
         self.assertEqual(test_superobs_fake_data, True)
+ 
+ 
+      def test_thinning_data(self):
+
+        ''' 
+          test funtion to make sure that modifications in the branch do not affect the result 
+        '''
+        import radvelso
+        import sqlite3
+        center_time = '2019062018'
+        center_time = datetime.datetime.strptime(center_time, '%Y%m%d%H')
+        radvelso.cthinning.compute_thinning( center_time = center_time,
+                           window_width = 6,                                             
+                           infile_list= ["radvelso_test/sqlite_files/infile_2019062018_superobbed_groundRadarDoppler.sqlite"],
+                           pathout = "work",
+                           outfile_struc= 'infile_%Y%m%d%H_superobbed_groundRadarDoppler.sqlite.thinning',               
+                           timing = False,
+                           n_cpus = 40,          
+                           delta_time_thinning_min = 15 , 
+                           delta_distance_neighbours_m = 100000,  
+                           delta_height_vertical_m = 1000, 
+                           delta_distance_couple_m = 1000,  
+                           pathin_model = "/home/sprj700/data_maestro/ppp6/maestro_archives/G2810E22V3/gridpt/prog/hyb/")
+              
+        db1 ="radvelso_test/sqlite_files/infile_2019062018_superobbed_groundRadarDoppler.sqlite.thinning"
+        
+        db2 ="work/infile_2019062018_superobbed_groundRadarDoppler.sqlite.thinning"
+        
+        
+        conn1 = sqlite3.connect(db1)
+        conn2 = sqlite3.connect(db2)
+        
+        res1 = conn1.execute("""SELECT count(*) FROM data where flag=0
+                               
+                            """).fetchall()
+        res2 = conn2.execute("""SELECT count(*) FROM data where flag=0
+        
+                            """).fetchall()
+        
+        res3 = conn1.execute("""SELECT obsvalue FROM data where flag=0 order by id_data ASC
+                               
+                            """).fetchall()
+        res4 = conn2.execute("""SELECT obsvalue FROM data where flag=0 order by id_data ASC
+
+        
+                            """).fetchall()
+
+        self.assertEqual((res1==res2) and (res3==res4), True)
+
+
+      def test_qcavg_data(self):
+
+        ''' 
+          test funtion to make sure that modifications in the branch do not affect the result 
+          
+        '''
+        import radvelso
+        import sqlite3
+
+        radvelso.qcavg.compute_qcavg( assim_T0 = datetime.datetime(2022,6,27,0),
+                                      assim_window_width = 6. ,  
+                                      desired_radar_list = ['casbv', 'casrf', 'ushgx', 'ushtx'],
+                                      infile_list= [ "/fs/site6/eccc/cmd/a/dlo001/shared/shared_test/radvelso_test/sqlite_files_qcavg_2022062700/CASBV/2022062700_ra",
+                                                     "/fs/site6/eccc/cmd/a/dlo001/shared/shared_test/radvelso_test/sqlite_files_qcavg_2022062700/CASRF/2022062700_ra", 
+                                                     "/fs/site6/eccc/cmd/a/dlo001/shared/shared_test/radvelso_test/sqlite_files_qcavg_2022062700/USHGX/2022062700_ra",
+                                                     "/fs/site6/eccc/cmd/a/dlo001/shared/shared_test/radvelso_test/sqlite_files_qcavg_2022062700/USHTX/2022062700_ra"],
+                                      pathout = "work",
+                                      outfile_struc= '%Y%m%d%H_superobbed_groundRadarDoppler.sqlite',               
+                                      ops_run_name =  'G1',
+                                      n_rays = 10,
+                                      delta_range = 10000.0,
+                                      n_cpus = 80,
+                                      obs_percentage = 50.0,
+                                      obs_nyquist = 28.0 ,
+                                      model_outputs_for_dealiasing= "/fs/site6/eccc/cmd/a/dlo001/shared/shared_test/radvelso_test/glbete2022.gript.trial.hyb/", 
+                                      model_files_search_pattern = "%Y%m%d%H_*m")
+        db1 ="radvelso_test/sqlite_files/2019062018_superobbed_groundRadarDoppler.sqlite"
+        
+        db2 ="work/2019062018_superobbed_groundRadarDoppler.sqlite"
+        
+        
+        conn1 = sqlite3.connect(db1)
+        conn2 = sqlite3.connect(db2)
+        
+        res1 = conn1.execute("""SELECT count(*) FROM data where flag=0
+                               
+                            """).fetchall()
+        res2 = conn2.execute("""SELECT count(*) FROM data where flag=0
+        
+                            """).fetchall()
+        
+        res3 = conn1.execute("""SELECT obsvalue FROM data where flag=0 order by obsvalue ASC
+                               
+                            """).fetchall()
+        res4 = conn2.execute("""SELECT obsvalue FROM data where flag=0 order by obsvalue ASC
+
+        
+                            """).fetchall()
+
+        self.assertEqual((res1==res2) and (res3==res4), True)
 
 
 if __name__ == '__main__':
